LogicalClock

Struct LogicalClock 

pub struct LogicalClock { /* private fields */ }
Represents a logical clock for maintaining causality.

Implementations

Source

impl LogicalClock

pub fn new() -> Self

Creates a new logical clock starting at 0

pub fn tick(&mut self) -> u64

Increments the clock for a local event and returns the new time

pub fn update(&mut self, received_time: u64) -> u64

Updates the clock based on a received time and returns the new time

pub fn set_time(&mut self, time: u64)

Sets the logical clock to a specific time

pub fn current_time(&self) -> u64

Retrieves the current time