Change

Struct Change 

pub struct Change<K, V> {
    pub record_id: K,
    pub col_name: Option<ColumnKey>,
    pub value: Option<V>,
    pub col_version: u64,
    pub db_version: u64,
    pub node_id: NodeId,
    pub local_db_version: u64,
    pub flags: u32,
}
Represents a single change in the CRDT.

A change can represent:

  • An insertion or update of a column value (when col_name is Some)
  • A deletion of a specific column (when col_name is Some and value is None)
  • A deletion of an entire record (when col_name is None)

Fields

record_id: Kcol_name: Option<ColumnKey>

None represents tombstone of the record

value: Option<V>

None represents deletion of the column (not the record)

col_version: u64db_version: u64node_id: NodeIdlocal_db_version: u64

Local db_version when the change was created (useful for get_changes_since)

flags: u32

Optional flags to indicate the type of change (ephemeral, not stored)

Implementations

Source

impl<K, V> Change<K, V>

pub fn new( record_id: K, col_name: Option<ColumnKey>, value: Option<V>, col_version: u64, db_version: u64, node_id: NodeId, local_db_version: u64, flags: u32, ) -> Self

Creates a new Change with all parameters